    	get address?

    		import netifaces

    		def get_all_ips():
    			ips = {}
    			for iface in netifaces.interfaces():
    				addresses = netifaces.ifaddresses(iface).setdefault(netifaces.AF_INET, [{'addr': 'No IP addr'}])
    				ips[iface] = [addr['addr'] for addr in addresses]
    			return ips

    		print(get_all_ips())

    		from urllib.request import urlopen
    		import re

    		def get_public_ip():
    			response = urlopen('http://checkip.dyndns.com/').read()
    			ip_address = re.search(r'Address: (\d+\.\d+\.\d+\.\d+)', response.decode('utf-8')).group(1)
    			return ip_address

    		print(get_public_ip())